Crate lash_postgres_store

Crate lash_postgres_store 

PostgreSQL durable storage for Lash.

One PostgresStorage owns a shared sqlx::PgPool and creates durable implementations for the runtime session store, process registry, trigger store, Lashlang artifact store, process execution environment store, and attachment manifest.

Structs

PostgresLashlangArtifactStore
PostgresProcessRegistry
PostgresSessionStore
PostgresSessionStoreFactory
PostgresStorage
PostgresStoreConfig
Connection-pool and per-connection timeout knobs for PostgresStorage.
PostgresTriggerStore